xsget package
=============

Submodules
----------

xsget.chapter module
--------------------

.. automodule:: xsget.chapter
   :members:
   :undoc-members:
   :show-inheritance:

xsget.xsget module
------------------

.. automodule:: xsget.xsget
   :members:
   :undoc-members:
   :show-inheritance:

xsget.xstxt module
------------------

.. automodule:: xsget.xstxt
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: xsget
   :members:
   :undoc-members:
   :show-inheritance:
